@@ -721,7 +721,8 @@ class MCCD(object):
             self.SNR_weight_list[k],
             self.upfact,
             self.Phi_filters,
-            save_iter_cost=self.iter_outputs) for k in range(self.n_ccd)]
+            save_iter_cost=self.iter_outputs,
+            verbose=self.verbose) for k in range(self.n_ccd)]
 
         weight_loc_grad = [grads.CoeffLocGrad(
             self.obs_data[k],
@@ -735,7 +736,8 @@ class MCCD(object):
             self.shift_ker_stack_adj[k],
             self.SNR_weight_list[k],
             self.upfact,
-            save_iter_cost=self.iter_outputs) for k in range(self.n_ccd)]
+            save_iter_cost=self.iter_outputs,
+            verbose=self.verbose) for k in range(self.n_ccd)]
 
         source_glob_grad = grads.SourceGlobGrad(
             conc(self.obs_data, axis=2),
@@ -749,7 +751,8 @@ class MCCD(object):
             conc(self.SNR_weight_list),
             self.upfact,
             self.Phi_filters,
-            save_iter_cost=self.iter_outputs)
+            save_iter_cost=self.iter_outputs,
+            verbose=self.verbose)
 
         weight_glob_grad = grads.CoeffGlobGrad(
             conc(self.obs_data, axis=2),
@@ -763,7 +766,8 @@ class MCCD(object):
             conc(self.shift_ker_stack_adj, axis=2),
             self.upfact,
             conc(self.SNR_weight_list),
-            save_iter_cost=self.iter_outputs)
+            save_iter_cost=self.iter_outputs,
+            verbose=self.verbose)
 
         # Proxs for component optimization
         sparsity_prox = prox.StarletThreshold(0)
@@ -872,7 +876,8 @@ class MCCD(object):
                             transf_comp[self.n_ccd],
                             source_glob_grad, sparsity_prox,
                             cost=source_glob_cost,
-                            beta_param=1. / beta, auto_iterate=False)
+                            beta_param=1. / beta, auto_iterate=False,
+                            verbose=self.verbose, progress=self.verbose)
                         source_optim.iterate(max_iter=self.nb_subiter_S_glob)
                         transf_comp[self.n_ccd] = source_optim.x_final
                         reweighter.reweight(transf_comp[self.n_ccd])
@@ -882,7 +887,8 @@ class MCCD(object):
                     source_optim = optimalg.ForwardBackward(
                         transf_comp[self.n_ccd],
                         source_glob_grad, sparsity_prox, cost=source_glob_cost,
-                        beta_param=1. / beta, auto_iterate=False)
+                        beta_param=1. / beta, auto_iterate=False,
+                        verbose=self.verbose, progress=self.verbose)
                     source_optim.iterate(max_iter=self.nb_subiter_S_glob)
                     transf_comp[self.n_ccd] = source_optim.x_final
 
@@ -933,7 +939,9 @@ class MCCD(object):
                                                cost=weight_glob_cost,
                                                max_iter=self.nb_subiter_A_glob,
                                                tau=tau,
-                                               sigma=sigma)
+                                               sigma=sigma,
+                                               verbose=self.verbose,
+                                               progress=self.verbose)
                 alpha[self.n_ccd] = weight_optim.x_final
                 weights_glob = [alpha[self.n_ccd].dot(self.Pi[k])
                                 for k in range(self.n_ccd)]
@@ -1001,7 +1009,9 @@ class MCCD(object):
                                 cost=source_loc_cost[k],
                                 max_iter=self.nb_subiter_S_loc,
                                 tau=tau,
-                                sigma=sigma)
+                                sigma=sigma,
+                                verbose=self.verbose,
+                                progress=self.verbose)
                             transf_comp[k] = source_optim.x_final
                             reweighter.reweight(transf_comp[k])
                             thresholds = reweighter.weights
@@ -1016,7 +1026,9 @@ class MCCD(object):
                             linear=lin_recombine[k],
                             cost=source_loc_cost[k],
                             max_iter=self.nb_subiter_S_loc,
-                            tau=tau, sigma=sigma)
+                            tau=tau, sigma=sigma,
+                            verbose=self.verbose,
+                            progress=self.verbose)
                         transf_comp[k] = source_optim.x_final
 
                         # Save iteration diagnostic data
@@ -1058,7 +1070,9 @@ class MCCD(object):
                         cost=weight_loc_cost[k],
                         max_iter=self.nb_subiter_A_loc,
                         tau=tau,
-                        sigma=sigma)
+                        sigma=sigma,
+                        verbose=self.verbose,
+                        progress=self.verbose)
                     alpha[k] = weight_optim.x_final
                     weights_loc[k] = alpha[k].dot(self.VT[k])
 
